activity_multiple_times_executed: activity sometimes multiple times executed
Description
This functions returns true or false on whether or not an activity is sometimes multiple times executed
This can be useful for measuring the understandability using behavioral profiles.