Learn R Programming

understandBPMN (version 1.1.1)

activity_names_repetitions: activity names repetitions

Description

This functions returns a list containing the repetitions with their respective activity names This can be useful for measuring the understandability using behavioral profiles.

Usage

activity_names_repetitions(repetition_and_path_log, xml_internal_doc)

Arguments

repetition_and_path_log

repetition and path log list object created by the function create_repetition_and_path_log

xml_internal_doc

document object created using the create_internal_document function

Value

a list containing the repetitions with their respective activity names

Examples

Run this code
# NOT RUN {
activity_multiple_times_executed(log, doc, "A")
# }

Run the code above in your browser using DataLab