Average connector degree is defined as the average incoming and outgoing sequence flows of all gateways and activities with at least two incoming or outgoing sequence flows
Usage
avg_connector_degree(file_path, signavio = FALSE)
Arguments
file_path
document object created using the create_internal_document function
signavio
boolean which indicates whether the file stems from signavio
Value
an integer indicating the average connector degree