Learn R Programming

understandBPMN (version 1.1.1)

cognitive_weight: Cognitive weights

Description

Cognitive weight is defined as a weighted sum of gateways and activities

Usage

cognitive_weight(file_path, signavio = FALSE)

Arguments

file_path

document object created using the create_internal_document function

signavio

boolean which indicates whether the file stems from signavio

Value

an integer indicating the control flow complexity

Examples

Run this code
# NOT RUN {
cognitive_weight(file_path)
# }

Run the code above in your browser using DataLab