Learn R Programming

understandBPMN (version 1.1.1)

connectivity_level_between_pools: The connectivity level between pools

Description

The connectivity level between pools is the number of message flows over the number of pools

Usage

connectivity_level_between_pools(file_path, signavio = FALSE)

Arguments

file_path

document object created using the create_internal_document function

signavio

boolean which indicates whether the file stems from signavio

Value

an integer indicating the connectivity level between pools

Examples

Run this code
# NOT RUN {
connectivity_level_between_pools(file_path)
# }

Run the code above in your browser using DataLab