Learn R Programming

understandBPMN (version 1.1.1)

connector_heterogeneity: Connector heterogeneity

Description

Connector heterogeneity is defined as the sum of minus - p times the log of p of all gateways. p is defined as the number of a particular type of gateway divided by all gateways.

Usage

connector_heterogeneity(file_path, signavio = FALSE)

Arguments

file_path

document object created using the create_internal_document function

signavio

boolean which indicates whether the file stems from signavio

Value

an integer indicating the connector heterogeneity

Examples

Run this code
# NOT RUN {
connector_heterogeneity(file_path)
# }

Run the code above in your browser using DataLab