Learn R Programming

understandBPMN (version 1.1.1)

connector_mismatch: Connector mismatch

Description

Connector mismatch is the absolute value of the difference between split gateways and join gateways for each type of gateway, ie parallel, exclusive, inclusive, complex and event based gateways

Usage

connector_mismatch(file_path, signavio = FALSE)

Arguments

file_path

document object created using the create_internal_document function

signavio

boolean which indicates whether the file stems from signavio

Value

an integer indicating the connector mismatch

Examples

Run this code
# NOT RUN {
connector_mismatch(file_path)
# }

Run the code above in your browser using DataLab