Learn R Programming

understandBPMN (version 1.1.1)

max_connector_degree: Maximum connector degree

Description

Maximum connector degree is defined as the gateway or activity with the most incoming and outgoing sequence flows

Usage

max_connector_degree(file_path, signavio = FALSE)

Arguments

file_path

document object created using the create_internal_document function

signavio

boolean which indicates whether the file stems from signavio

Value

an integer indicating the maximum connector degree

Examples

Run this code
# NOT RUN {
max_connector_degree(file_path)
# }

Run the code above in your browser using DataLab