Learn R Programming

understandBPMN (version 1.1.1)

some_traces_without_activity: activity sometimes not in traces

Description

This functions returns true or false on whether or not an activity is sometimes not part of a trace This can be useful for measuring the understandability using behavioral profiles.

Usage

some_traces_without_activity(repetition_and_path_log, xml_internal_doc,
  activity)

Arguments

repetition_and_path_log

repetition and path log list object created by the function create_repetition_and_path_log

xml_internal_doc

document object created using the create_internal_document function

activity

the activity name

Value

a boolean value indicating whether it is true on whether or not an activity is sometimes not part of a trace

Examples

Run this code
# NOT RUN {
some_traces_without_activity(log, doc, "A")
# }

Run the code above in your browser using DataLab