powered by
This functions returns a list containing the repetitions with their respective activity names This can be useful for measuring the understandability using behavioral profiles.
activity_names_repetitions(repetition_and_path_log, xml_internal_doc)
repetition and path log list object created by the function create_repetition_and_path_log
document object created using the create_internal_document function
a list containing the repetitions with their respective activity names
# NOT RUN { activity_multiple_times_executed(log, doc, "A") # }
Run the code above in your browser using DataLab