powered by
Cognitive weight is defined as a weighted sum of gateways and activities
cognitive_weight(file_path, signavio = FALSE)
document object created using the create_internal_document function
boolean which indicates whether the file stems from signavio
an integer indicating the control flow complexity
# NOT RUN { cognitive_weight(file_path) # }
Run the code above in your browser using DataLab