powered by
The connectivity level between pools is the number of message flows over the number of pools
connectivity_level_between_pools(file_path, signavio = FALSE)
document object created using the create_internal_document function
boolean which indicates whether the file stems from signavio
an integer indicating the connectivity level between pools
# NOT RUN { connectivity_level_between_pools(file_path) # }
Run the code above in your browser using DataLab