powered by
Connector heterogeneity is defined as the sum of minus - p times the log of p of all gateways. p is defined as the number of a particular type of gateway divided by all gateways.
connector_heterogeneity(file_path, signavio = FALSE)
document object created using the create_internal_document function
boolean which indicates whether the file stems from signavio
an integer indicating the connector heterogeneity
# NOT RUN { connector_heterogeneity(file_path) # }
Run the code above in your browser using DataLab