powered by
Maximum connector degree is defined as the gateway or activity with the most incoming and outgoing sequence flows
max_connector_degree(file_path, signavio = FALSE)
document object created using the create_internal_document function
boolean which indicates whether the file stems from signavio
an integer indicating the maximum connector degree
# NOT RUN { max_connector_degree(file_path) # }
Run the code above in your browser using DataLab