some_traces_without_activity: activity sometimes not in traces
Description
This functions returns true or false on whether or not an activity is sometimes not part of a trace
This can be useful for measuring the understandability using behavioral profiles.